from sqlalchemy import create_engine, Column, Integer, String, text, func
from sqlalchemy.orm import declarative_base, sessionmaker
from sqlalchemy.sql import select

Base = declarative_base()

class User(Base):
    __tablename__ = 'users'

    id = Column(Integer, primary_key=True)
    name = Column(String)
    age = Column(Integer)

class Database:
    def __init__(self, connection_string):
        self.engine = create_engine(connection_string)
        self.Session = sessionmaker(bind=self.engine)
        self.session = self.Session()

    def test_connection(self):
        try:
            connection = self.engine.connect()
            connection.close()
            return True
        except Exception as e:
            print(f"Error: {e}")
            return False



from setuptools import setup, find_packages

setup(
    name="astakosa",
    version="0.1.5",
    packages=find_packages(),
    install_requires=[
        "sqlalchemy",
    ],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)